@@ -7,11 +7,14 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei ole käytössä! Lataa sivu uudelleen!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista lisätiedot lokitiedostosta data/nextcloud.log!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan ylläpitotilassa!",
+    "News feeds" : "Syötteet",
     "Unread articles" : "Lukemattomat artikkelit",
     "News" : "Uutiset",
+    "News folders" : "Syötekansiot",
     "Shared with me" : "Jaettu kanssasi",
     "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
     "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
+    "Disable this if you use a custom updater." : "Poista tämä käytöstä, jos käytät erillistä päivitintä.",
     "Purge interval" : "Hävitysväli",
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Minimiaika sekunteina jonka jälkeen poistetut syötteet ja kansiot poistetaan tietokannasta; alle 60 sekuntin arvot ohitetaan.",
     "Maximum read count per feed" : "Syötekohtainen lukukertojen enimmäismäärä",
@@ -19,9 +22,12 @@ OC.L10N.register(
     "How many redirects the feed fetcher should follow." : "Kuinka montaa uudelleenohjausta syötteen noutajan tulisi seurata.",
     "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimiaika sekunteina, jonka aikana RSS- tai Atom-syöte odotetaan ladattavaksi. Jos lataus kestää pidempään, se perutaan.",
+    "Explore Service URL" : "Syöte-ehdotusten palvelun URL",
+    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Palvelun osoite, josta haetaan ehdotuksia syötteistä Löydä uusia-osioon. Jätä tyhjäksi, jos haluat käyttää sisäänrakennettua oletuspalvelua.",
     "For more information check the wiki." : "Lue lisätietoja wikistä.",
     "Update interval" : "Päivitysväli",
     "Interval in seconds in which the feeds will be updated." : "Syötteiden päivitysväli sekunteina.",
+    "For more information check the documentation." : "Lue lisätietoja dokumentaatiosta.",
     "Saved" : "Tallennettu",
     "Download" : "Lataa",
     "Close" : "Sulje",
@@ -37,7 +43,10 @@ OC.L10N.register(
     "Share with users" : "Jaa käyttäjien kanssa",
     "Username" : "Käyttäjätunnus",
     "No users found" : "Käyttäjiä ei löytynyt",
+    "Error while searching for users" : "Virhe käyttäjien etsinnässä",
     "Share on social media" : "Jaa sosiaalisessa mediassa",
+    "I wanted you to see this article" : "Halusin sinun näkevän tämän artikkelin",
+    "Check out this article" : "Katso tämä artikkeli",
     "by" : "Kirjoittaja:",
     "from" : "Syöte:",
     "shared by" : "jakanut",
@@ -77,9 +86,10 @@ OC.L10N.register(
     "Folder exists already!" : "Kansio on jo olemassa!",
     "Credentials" : "Tilitiedot",
     "Password" : "Salasana",
+    "Auto discover Feed" : "Löydä syöte automaattisesti",
     "New Folder" : "Uusi kansio",
     "Create" : "Luo",
-    "Explore" : "Selaa",
+    "Explore" : "Löydä uusia",
     "Update failed more than 50 times" : "Päivitys epäonnistui yli 50 kertaa",
     "Deleted feed" : "Syöte poistettu",
     "Undo delete feed" : "Kumoa syötteen poistaminen",
@@ -91,8 +101,8 @@ OC.L10N.register(
     "Newest first" : "Uusin ensin",
     "Oldest first" : "Vanhin ensin",
     "Default order" : "Oletusjärjestys",
-    "Enable full text" : "Käytä koko tekstiä",
-    "Disable full text" : "Poista käytöstä koko teksti",
+    "Enable full text" : "Lataa koko teksti",
+    "Disable full text" : "Älä lataa koko tekstiä",
     "Open feed URL" : "Avaa syötteen osoite",
     "Delete" : "Poista",
     "Dismiss" : "Hylkää",
