@@ -7,6 +7,7 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Срок действия токена истёк или приложение не включено! Перезагрузите страницу!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Внутренняя ошибка сервера! Пожалуйста, для получения дополнительной информации проверьте журнал в файле data/nextcloud.log!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Запрос не удался, в настоящий момент Nextcloud включен в режиме обслуживания!",
+    "News feeds" : "Новостные ленты",
     "Unread articles" : "Непрочтённые статьи",
     "News" : "Новости",
     "News folders" : "Каталог новостей",
@@ -26,6 +27,7 @@ OC.L10N.register(
     "For more information check the wiki." : "Для получения дополнительной информации обратитесь к wiki",
     "Update interval" : "Интервал обновления",
     "Interval in seconds in which the feeds will be updated." : "Интервал обновления лент в секундах",
+    "For more information check the documentation." : "Для подробной информации обратитесь к документации.",
     "Saved" : "Сохранено",
     "Download" : "Скачать",
     "Close" : "Закрыть",
